@@ -173,7 +173,7 @@ def to_txn(specs_to_add, specs_to_remove, prefix, to_link, to_unlink, index=None
     conda_transaction = UnlinkLinkTransaction(pref_setup)
     return conda_transaction
 
-use_mamba_download = False
+use_mamba_experimental = False
 
 def handle_txn(unlink_link_transaction, prefix, args, newenv, remove_op=False):
     if unlink_link_transaction.nothing_to_do:
@@ -187,12 +187,7 @@ def handle_txn(unlink_link_transaction, prefix, args, newenv, remove_op=False):
                 print('\n# All requested packages already installed.\n')
             return
 
-    # don't confirm / print if using mamba for download
-    if not context.json and not use_mamba_download:
-        unlink_link_transaction.print_transaction_summary()
-        confirm_yn()
-
-    elif context.dry_run:
+    if context.dry_run:
         actions = unlink_link_transaction._make_legacy_action_groups()[0]
         cli_common.stdout_json_success(prefix=prefix, actions=actions, dry_run=True)
         raise DryRunExit()
@@ -274,8 +269,8 @@ def remove(args, parser):
             specs = tuple(MatchSpec(track_features=f) for f in set(args.package_names))
         else:
             specs = [s for s in specs_from_args(args.package_names)]
-        if not (context.quiet or context.json):
-            print("Removing specs: {}".format(specs))
+        if not context.quiet:
+            print("Removing specs: {}".format([s.conda_build_form() for s in specs]))
         channel_urls = ()
         subdirs = ()
 
@@ -289,9 +284,15 @@ def remove(args, parser):
         repos = []
 
         # add installed
-        repo = api.Repo(pool, "installed", installed_json_f.name, "")
-        repo.set_installed()
-        repos.append(repo)
+        if use_mamba_experimental:
+            prefix_data = api.PrefixData(context.target_prefix)
+            prefix_data.load()
+            repo = api.Repo(pool, prefix_data)
+            repos.append(repo)
+        else:
+            repo = api.Repo(pool, "installed", installed_json_f.name, "")
+            repo.set_installed()
+            repos.append(repo)
 
         solver = api.Solver(pool, solver_options)
         solver.add_jobs(mamba_solve_specs, api.SOLVER_ERASE)
@@ -417,6 +418,10 @@ def install(args, parser, command='install'):
 
         subpriority = 0 if chan.platform == 'noarch' else 1
 
+        if subdir.loaded() == False and chan.platform != 'noarch':
+            # ignore non-loaded subdir if channel is != noarch
+            continue
+
         if context.verbosity != 0:
             print("Cache path: ", subdir.cache_path())
         channel_json.append((chan, subdir.cache_path(), priority, subpriority))
@@ -495,9 +500,16 @@ def install(args, parser, command='install'):
     repos = []
 
     # add installed
-    repo = api.Repo(pool, "installed", installed_json_f.name, "")
-    repo.set_installed()
-    repos.append(repo)
+    if use_mamba_experimental:
+        prefix_data = api.PrefixData(context.target_prefix)
+        prefix_data.load()
+        repo = api.Repo(pool, prefix_data)
+        repos.append(repo)
+    else:
+        repo = api.Repo(pool, "installed", installed_json_f.name, "")
+        repo.set_installed()
+        repos.append(repo)
+
 
     for channel, cache_file, priority, subpriority in channel_json:
         repo = api.Repo(pool, str(channel), cache_file, channel.url(with_credentials=True))
@@ -516,11 +528,10 @@ def install(args, parser, command='install'):
     to_link, to_unlink = transaction.to_conda()
     transaction.log_json()
 
-    if use_mamba_download:
-        downloaded = transaction.prompt(PackageCacheData.first_writable().pkgs_dir, repos)
-        if not downloaded:
-            exit(0)
-        PackageCacheData.first_writable().reload()
+    downloaded = transaction.prompt(PackageCacheData.first_writable().pkgs_dir, repos)
+    if not downloaded:
+        exit(0)
+    PackageCacheData.first_writable().reload()
 
     if python_added:
         specs = [s for s in specs if s.name != 'python']
@@ -577,11 +588,6 @@ def repoquery(args, parser):
         'use_local': args.use_local
     }
 
-    index = get_index(channel_urls=index_args['channel_urls'],
-                  prepend=index_args['prepend'], platform=None,
-                  use_local=index_args['use_local'], use_cache=index_args['use_cache'],
-                  unknown=index_args['unknown'], prefix=prefix)
-
     installed_json_f = get_installed_jsonfile(prefix)
 
     pool = api.Pool()
@@ -593,7 +599,16 @@ def repoquery(args, parser):
     repos.append(repo)
 
     if not args.installed:
+        index = get_index(channel_urls=index_args['channel_urls'],
+                      prepend=index_args['prepend'], platform=None,
+                      use_local=index_args['use_local'], use_cache=index_args['use_cache'],
+                      unknown=index_args['unknown'], prefix=prefix)
+
         for subdir, channel in index:
+            if subdir.loaded() == False and channel.platform != 'noarch':
+                # ignore non-loaded subdir if channel is != noarch
+                continue
+
             repo = api.Repo(pool, str(channel), subdir.cache_path(), channel.url(with_credentials=True))
             repo.set_priority(0, 0)
             repos.append(repo)
@@ -604,6 +619,8 @@ def repoquery(args, parser):
     query = api.Query(pool)
     if args.whatrequires:
         print(query.whatrequires(args.query))
+    elif args.tree:
+        print(query.dependencytree(args.query))
     else:
         print(query.find(args.query))
 
@@ -671,6 +688,12 @@ Examples:
         help=SUPPRESS,
     )
 
+    p.add_argument(
+        "--tree",
+        action="store_true",
+        help=SUPPRESS,
+    )
+
     from conda.cli import conda_argparse
     conda_argparse.add_parser_channels(p)
     conda_argparse.add_parser_networking(p)
@@ -686,11 +709,13 @@ def _wrapped_main(*args, **kwargs):
 
     import copy
     argv = list(args)
-    if "--mamba-download" in argv:
-        global use_mamba_download
-        use_mamba_download = True
-        argv.remove('--mamba-download')
-        args = argv
+
+    if "--mamba-experimental" in argv:
+        global use_mamba_experimental
+        use_mamba_experimental = True
+        argv.remove('--mamba-experimental')
+
+    args = argv
 
     p = generate_parser()
     configure_parser_repoquery(p._subparsers._group_actions[0])
